### 关于当前运行

项目 | 对应值
--- | ---
PyCheer版本 | {VERSION}
运行目录 | {WORKDIR}

### 关于本软件

项目 | 对应值
--- | ---
软件作者 | cyrxdzj
Gitee地址 | https://gitee.com/cyrxdzj/PyCheer
开源许可证 | MulanPSL-2.0

### 使用的开源软件

软件名 | 开源许可证 | 用途
--- | --- | ---
Flask | BSD 3-Clause "New" or "Revised" License | 服务端的服务框架。
Ace | BSD开源许可证 | 用于代码编辑区域。
Axios | MIT License | 用于浏览器向服务端发起请求。
Bootstrap | MIT License | 用于界面UI。
jQuery | MIT License | 支撑Bootstrap运行。
SweetAlert | MIT License | 用于弹出对话框。
Markdown*Palettes | （未指定） | 用于Markdown编辑器。